Image Operations
================

This section presents a set of functions for the purpose of image creation, manipulation and enhancement. 
These functions are explicitly intended for direct application to images, granting users the capacity to rectify illumination disparities or gain valuable insights into image attributes such as dimensions and color channels.

.. toctree::
   :maxdepth: 1

   functions/illumination_correction/absolute_difference
   functions/make_mask/circlair_mask
   functions/make_mask/ellipse_mask
   functions/make_mask/contour_mask_maker
   functions/convert_color/convert_color
   functions/illumination_correction/fluo_tophat
   functions/img_dim/img_dim
   functions/img_paste/img_paste
   functions/illumination_correction/relative_difference

